@@ -31,7 +31,6 @@ if __name__ == "__main__":
         #"password":password,
         "driverLocation":driverLocation,
         "query":query,
-        #"rowAll":rowAll,
         "thisPluginName":thisPluginName,
     }
     if not passDbConnection:
@@ -71,6 +70,7 @@ if __name__ == "__main__":
         call(f"touch {fileDestination}", shell=True)
     open(fileDestination, 'w').write(f'''#!/usr/bin/python3.6
 import json
+from site24x7_plugin_helper.connector import guessMetricByType
 cacheData = json.loads(open("{cacheFileName}").read())
 PLUGIN_VERSION = "2"
 HEARTBEAT = "true"
@@ -79,10 +79,10 @@ METRIC_UNITS = {{}}
 
 def metricCollector():
     data = {{}}
+    guessMetricByType(data, cacheData)
     data["plugin_version"] = PLUGIN_VERSION
     data['heartbeat_required'] = HEARTBEAT
     data["CPU"] = 100
-    # data["FREQUENCY"] = FREQUENCY
     for i in cacheData:
         data[i] = cacheData[i]
     return data
